from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from yeying.api.common import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class SearchApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchApplicationRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: SearchCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[SearchCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class SearchCondition(_message.Message):
    __slots__ = ("code", "status", "owner", "name", "keyword")
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    KEYWORD_FIELD_NUMBER: _ClassVar[int]
    code: _code_pb2.ApplicationCodeEnum
    status: _code_pb2.ApplicationStatusEnum
    owner: str
    name: str
    keyword: str
    def __init__(
        self,
        code: _Optional[_Union[_code_pb2.ApplicationCodeEnum, str]] = ...,
        status: _Optional[_Union[_code_pb2.ApplicationStatusEnum, str]] = ...,
        owner: _Optional[str] = ...,
        name: _Optional[str] = ...,
        keyword: _Optional[str] = ...,
    ) -> None: ...

class SearchApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchApplicationResponseBody(_message.Message):
    __slots__ = ("status", "applications", "page")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    applications: _containers.RepeatedCompositeFieldContainer[_model_pb2.ApplicationMetadata]
    page: _message_pb2.ResponsePage
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        applications: _Optional[_Iterable[_Union[_model_pb2.ApplicationMetadata, _Mapping]]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
    ) -> None: ...

class CreateApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateApplicationRequestBody(_message.Message):
    __slots__ = ("application",)
    APPLICATION_FIELD_NUMBER: _ClassVar[int]
    application: _model_pb2.ApplicationMetadata
    def __init__(self, application: _Optional[_Union[_model_pb2.ApplicationMetadata, _Mapping]] = ...) -> None: ...

class CreateApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateApplicationResponseBody(_message.Message):
    __slots__ = ("status", "application")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    application: _model_pb2.ApplicationMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        application: _Optional[_Union[_model_pb2.ApplicationMetadata, _Mapping]] = ...,
    ) -> None: ...

class ApplicationDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ApplicationDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ApplicationDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ApplicationDetailRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class ApplicationDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ApplicationDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ApplicationDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ApplicationDetailResponseBody(_message.Message):
    __slots__ = ("status", "application")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    application: _model_pb2.ApplicationMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        application: _Optional[_Union[_model_pb2.ApplicationMetadata, _Mapping]] = ...,
    ) -> None: ...

class OfflineApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OfflineApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OfflineApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class OfflineApplicationRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class OfflineApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OfflineApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OfflineApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class OfflineApplicationResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class OnlineApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OnlineApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OnlineApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class OnlineApplicationRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class OnlineApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OnlineApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OnlineApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class OnlineApplicationResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class ApplicationExtend(_message.Message):
    __slots__ = ("comments",)
    COMMENTS_FIELD_NUMBER: _ClassVar[int]
    comments: _containers.RepeatedCompositeFieldContainer[ApplicationComment]
    def __init__(self, comments: _Optional[_Iterable[_Union[ApplicationComment, _Mapping]]] = ...) -> None: ...

class ApplicationComment(_message.Message):
    __slots__ = ("auditor", "comment", "passed", "signature")
    AUDITOR_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    PASSED_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    auditor: str
    comment: str
    passed: bool
    signature: str
    def __init__(
        self,
        auditor: _Optional[str] = ...,
        comment: _Optional[str] = ...,
        passed: bool = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class DeleteApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteApplicationRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DeleteApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteApplicationResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class AuditApplicationRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditApplicationRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditApplicationRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AuditApplicationRequestBody(_message.Message):
    __slots__ = ("comment", "did", "version")
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    comment: ApplicationComment
    did: str
    version: int
    def __init__(
        self,
        comment: _Optional[_Union[ApplicationComment, _Mapping]] = ...,
        did: _Optional[str] = ...,
        version: _Optional[int] = ...,
    ) -> None: ...

class AuditApplicationResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditApplicationResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditApplicationResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AuditApplicationResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding:utf-8 -*-
import uuid

from google.protobuf.json_format import MessageToJson
from yeying.api.asset import recycle_pb2, link_pb2_grpc, link_pb2, LinkTypeEnum
from yeying.api.common import ResponseCodeEnum, message_pb2
from yeying.client.provider.base_provider import BaseProvider
import grpc
from yeying.client.utils import log_utils
from yeying.client.utils.date_utils import get_current_utc_string, plus_second, get_current_utc_datetime, to_iso

log = log_utils.get_logger(__name__)


"""
LinkProvider 类提供对资产分享链接的管理
"""
class LinkProvider(BaseProvider):

    def __init__(self, **kw):
        super(LinkProvider, self).__init__(**kw)
        self.link_client = link_pb2_grpc.LinkStub(grpc.insecure_channel(self.option.proxy))

    def search(self, page, page_size, condition: link_pb2.SearchLinkCondition=None):
        """
        搜索资产分享链接
        :param page:当前页码
        :param page_size:每页显示的条目数
        :param condition:可选，搜索某个资产的分享链接。
        :return:
        """
        body = link_pb2.SearchLinkRequestBody(condition=condition, page=message_pb2.RequestPage(page=page, pageSize=page_size))
        header = self.authenticate.create_header(body=body)
        request = link_pb2.SearchLinkRequest(header=header, body=body)
        response: link_pb2.SearchLinkResponse = self.link_client.Search(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"search error, response={MessageToJson(response)}")
        return response

    def create(
        self,
        namespaceId: str,
        name: str,
        _hash: str,
        duration: int,
        _type: LinkTypeEnum,
        visitors: list[str],
        description: str
    ) -> link_pb2.CreateLinkResponse:
        """
        创建资产分享链接
        :param namespaceId:资产命名空间
        :param name:分享链接的名称
        :param _hash:要分享的资产哈希值
        :param duration:分享链接有效时长，单位是秒
        :param _type:分享链接类型
        :param visitors:指定具体的访问者
        :param description:描述
        :return:
        """
        link = link_pb2.LinkMetadata(
            owner=self.authenticate.get_did(),
            uid=str(uuid.uuid4()),
            type=_type,
            visitors=",".join(visitors) if visitors and len(visitors) > 0 else None,
            namespaceId=namespaceId,
            name=name,
            description=description,
            hash=_hash,
            startedAt=get_current_utc_string(),
            expiredAt=to_iso(plus_second(get_current_utc_datetime(), duration)),
            createdAt=get_current_utc_string()
        )
        link.signature = self.authenticate.sign_data(link.SerializeToString())
        body = link_pb2.CreateLinkRequestBody(link=link)
        header = self.authenticate.create_header(body=body)
        request = link_pb2.CreateLinkRequest(header=header, body=body)
        response: link_pb2.CreateLinkResponse = self.link_client.Create(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"create error, response={MessageToJson(response)}")
        return response

    def detail(self, uid: str) -> link_pb2.LinkDetailResponse:
        """
        获得资产分享链接详情
        :param uid:分享链接唯一ID
        :return:分享链接详情
        """
        body = link_pb2.LinkDetailRequestBody(uid=uid)
        header = self.authenticate.create_header(body=body)
        request = link_pb2.LinkDetailRequest(header=header, body=body)
        response: link_pb2.LinkDetailResponse = self.link_client.Detail(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"detail error, response={MessageToJson(response)}")
        return response

    def disable(self, uid: str) -> link_pb2.DisableLinkResponse:
        """
        取消资产分享
        :param uid:分享链接唯一ID
        :return:分享链接详情
        """
        body = link_pb2.DisableLinkRequestBody(linkId=uid)
        header = self.authenticate.create_header(body=body)
        request = link_pb2.DisableLinkRequest(header=header, body=body)
        response: link_pb2.DisableLinkResponse = self.link_client.Disable(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"disable error, response={MessageToJson(response)}")
        return response

    def visitors(self, uid: str, page: int, page_size: int) -> link_pb2.LinkVisitorResponse:
        """
        获得资产链接访问者
        :param uid:分享链接唯一ID
        :param page:当前页码
        :param page_size:每页显示的条目数
        :return:资产链接访问者列表
        """
        body = link_pb2.LinkVisitorRequestBody(uid=uid, page=message_pb2.RequestPage(page=page, pageSize=page_size))
        header = self.authenticate.create_header(body=body)
        request = link_pb2.LinkVisitorRequest(header=header, body=body)
        response: link_pb2.LinkVisitorResponse = self.link_client.Visitor(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"visitors error, response={MessageToJson(response)}")
        return response


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.application import application_pb2 as yeying_dot_api_dot_application_dot_application__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/application/application_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class ApplicationStub(object):
    """*
    节点自带的应用和后面发布的应用，夜莺社区提供一个节点和一组组网协议。当然其他的社团或者个人，也可以基于源代码，发布自己的节点和一组组网协议，当然
    也可以加入到夜莺社区的网络。
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Search = channel.unary_unary(
            "/yeying.api.application.Application/Search",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationResponse.FromString,
            _registered_method=True,
        )
        self.Audit = channel.unary_unary(
            "/yeying.api.application.Application/Audit",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationResponse.FromString,
            _registered_method=True,
        )
        self.Create = channel.unary_unary(
            "/yeying.api.application.Application/Create",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationResponse.FromString,
            _registered_method=True,
        )
        self.Detail = channel.unary_unary(
            "/yeying.api.application.Application/Detail",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailResponse.FromString,
            _registered_method=True,
        )
        self.Offline = channel.unary_unary(
            "/yeying.api.application.Application/Offline",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationResponse.FromString,
            _registered_method=True,
        )
        self.Online = channel.unary_unary(
            "/yeying.api.application.Application/Online",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationResponse.FromString,
            _registered_method=True,
        )
        self.Delete = channel.unary_unary(
            "/yeying.api.application.Application/Delete",
            request_serializer=yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationResponse.FromString,
            _registered_method=True,
        )


class ApplicationServicer(object):
    """*
    节点自带的应用和后面发布的应用，夜莺社区提供一个节点和一组组网协议。当然其他的社团或者个人，也可以基于源代码，发布自己的节点和一组组网协议，当然
    也可以加入到夜莺社区的网络。
    """

    def Search(self, request, context):
        """搜索应用"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Audit(self, request, context):
        """应用审计"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Create(self, request, context):
        """创建应用"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Detail(self, request, context):
        """应用详情"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Offline(self, request, context):
        """下架应用"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Online(self, request, context):
        """上架应用"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Delete(self, request, context):
        """删除应用"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ApplicationServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationResponse.SerializeToString,
        ),
        "Audit": grpc.unary_unary_rpc_method_handler(
            servicer.Audit,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationResponse.SerializeToString,
        ),
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationResponse.SerializeToString,
        ),
        "Detail": grpc.unary_unary_rpc_method_handler(
            servicer.Detail,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailResponse.SerializeToString,
        ),
        "Offline": grpc.unary_unary_rpc_method_handler(
            servicer.Offline,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationResponse.SerializeToString,
        ),
        "Online": grpc.unary_unary_rpc_method_handler(
            servicer.Online,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationResponse.SerializeToString,
        ),
        "Delete": grpc.unary_unary_rpc_method_handler(
            servicer.Delete,
            request_deserializer=yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationRequest.FromString,
            response_serializer=yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.application.Application", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.application.Application", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Application(object):
    """*
    节点自带的应用和后面发布的应用，夜莺社区提供一个节点和一组组网协议。当然其他的社团或者个人，也可以基于源代码，发布自己的节点和一组组网协议，当然
    也可以加入到夜莺社区的网络。
    """

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Search",
            yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.SearchApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Audit(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Audit",
            yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.AuditApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Create",
            yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.CreateApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Detail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Detail",
            yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.ApplicationDetailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Offline(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Offline",
            yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.OfflineApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Online(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Online",
            yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.OnlineApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Delete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.application.Application/Delete",
            yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationRequest.SerializeToString,
            yeying_dot_api_dot_application_dot_application__pb2.DeleteApplicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by protobuf_init. Do not edit manually.
from .contract_pb2 import CreateAddressRequest
from .contract_pb2 import CreateAddressResponse
from .contract_pb2 import TransactionRequest
from .contract_pb2 import TransactionResponse
from .contract_pb2 import BalanceRequest
from .contract_pb2 import BalanceResponse
from .contract_pb2 import WalletInfoRequest
from .contract_pb2 import WalletInfoResponse
from .contract_pb2 import Transaction
from .contract_pb2_grpc import WalletServicer
from .contract_pb2_grpc import WalletStub
from .contract_pb2_grpc import add_WalletServicer_to_server
from .contract_pb2_grpc import Wallet



# Generated by protobuf_init. Do not edit manually.
from .invitation_pb2 import InvitationMetadata
from .invitation_pb2 import InvitationUseState
from .invitation_pb2 import CreateInvitationRequest
from .invitation_pb2 import CreateInvitationRequestBody
from .invitation_pb2 import CreateInvitationResponse
from .invitation_pb2 import CreateInvitationResponseBody
from .invitation_pb2 import SearchInvitationRequest
from .invitation_pb2 import SearchInvitationRequestBody
from .invitation_pb2 import SearchInvitationResponse
from .invitation_pb2 import SearchInvitationResponseBody
from .invitation_pb2 import InvitationDetailRequest
from .invitation_pb2 import InvitationDetailRequestBody
from .invitation_pb2 import InvitationDetailResponse
from .invitation_pb2 import InvitationDetailResponseBody
from .invitation_pb2 import InvitationSceneEnum
from .invitation_pb2_grpc import InvitationServicer
from .invitation_pb2_grpc import InvitationStub
from .invitation_pb2_grpc import add_InvitationServicer_to_server
from .invitation_pb2_grpc import Invitation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/llm/provider.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/llm/provider.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/llm/provider.proto\x12\x0eyeying.api.llm\x1a\x1fyeying/api/common/message.proto"O\n\x1bProviderDescriptionsRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x90\x01\n\x1cProviderDescriptionsResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.llm.ProviderDescriptionsResponseBody"\x90\x01\n ProviderDescriptionsResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32#.yeying.api.llm.ProviderDescription"\x82\x01\n\x15ProviderModelsRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.ProviderModelsRequestBody"}\n\x19ProviderModelsRequestBody\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x30\n\tmodelType\x18\x02 \x01(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum"\x84\x01\n\x16ProviderModelsResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.ProviderModelsResponseBody"~\n\x1aProviderModelsResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x06models\x18\x02 \x03(\x0b\x32\x1d.yeying.api.llm.ModelMetadata"\x82\x01\n\x15\x44\x65leteProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.DeleteProviderRequestBody"(\n\x19\x44\x65leteProviderRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x84\x01\n\x16\x44\x65leteProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.DeleteProviderResponseBody"O\n\x1a\x44\x65leteProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x82\x01\n\x15SearchProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.SearchProviderRequestBody"\x85\x01\n\x19SearchProviderRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage\x12:\n\tcondition\x18\x02 \x01(\x0b\x32\'.yeying.api.llm.SearchProviderCondition"\x84\x01\n\x16SearchProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.SearchProviderResponseBody"\x84\x01\n\x1aSearchProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\tproviders\x18\x02 \x03(\x0b\x32 .yeying.api.llm.ProviderMetadata"|\n\x12\x41\x64\x64ProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.llm.AddProviderRequestBody"L\n\x16\x41\x64\x64ProviderRequestBody\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata"~\n\x13\x41\x64\x64ProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.llm.AddProviderResponseBody"\x80\x01\n\x17\x41\x64\x64ProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x32\n\x08provider\x18\x02 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata"\x82\x01\n\x15ProviderDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.ProviderDetailRequestBody"(\n\x19ProviderDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x84\x01\n\x16ProviderDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.ProviderDetailResponseBody"\x7f\n\x1aProviderDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1e.yeying.api.llm.ProviderDetail"r\n\x0eProviderDetail\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata\x12,\n\x05state\x18\x02 \x01(\x0b\x32\x1d.yeying.api.llm.ProviderState"\xb4\x01\n\x13ProviderDescription\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12:\n\x13supportedModelTypes\x18\x04 \x03(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum\x12\x0e\n\x06\x61vatar\x18\x05 \x01(\t"I\n\x17SearchProviderCondition\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum"\xfb\x01\n\x10ProviderMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12.\n\x04\x63ode\x18\x04 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x30\n\tquotaType\x18\x06 \x01(\x0e\x32\x1d.yeying.api.llm.QuotaTypeEnum\x12\x12\n\nquotaLimit\x18\x07 \x01(\x04\x12\x11\n\tcreatedAt\x18\x08 \x01(\t\x12\x11\n\tupdatedAt\x18\t \x01(\t\x12\x11\n\tsignature\x18\n \x01(\t"\xb6\x01\n\rModelMetadata\x12\x36\n\x0cproviderCode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\x08\x66\x65\x61tures\x18\x04 \x03(\x0e\x32 .yeying.api.llm.ModelFeatureEnum"\xb0\x01\n\rProviderState\x12\x12\n\nserviceDid\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32".yeying.api.llm.ProviderStatusEnum\x12\x11\n\tquotaUsed\x18\x04 \x01(\x04\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t*\xd7\x01\n\rModelTypeEnum\x12\x16\n\x12MODEL_TYPE_UNKNOWN\x10\x00\x12\x12\n\x0eMODEL_TYPE_LLM\x10\x01\x12\x1d\n\x19MODEL_TYPE_TEXT_EMBEDDING\x10\x02\x12\x15\n\x11MODEL_TYPE_RERANK\x10\x03\x12\x1a\n\x16MODEL_TYPE_SPEECH2TEXT\x10\x04\x12\x12\n\x0eMODEL_TYPE_TTS\x10\x05\x12\x19\n\x15MODEL_TYPE_MODERATION\x10\x06\x12\x19\n\x15MODEL_TYPE_TEXT2IMAGE\x10\x07*\xff\x01\n\x10ModelFeatureEnum\x12\x1f\n\x1bMODEL_FEATURE_AGENT_THOUGHT\x10\x00\x12\x18\n\x14MODEL_FEATURE_VISION\x10\x02\x12\x1b\n\x17MODEL_FEATURE_TOOL_CALL\x10\x03\x12!\n\x1dMODEL_FEATURE_MULTI_TOOL_CALL\x10\x04\x12"\n\x1eMODEL_FEATURE_STREAM_TOOL_CALL\x10\x05\x12\x1a\n\x16MODEL_FEATURE_DOCUMENT\x10\x06\x12\x17\n\x13MODEL_FEATURE_VIDEO\x10\x07\x12\x17\n\x13MODEL_FEATURE_AUDIO\x10\x08*\xb0\x01\n\x10ProviderCodeEnum\x12\x19\n\x15PROVIDER_CODE_UNKNOWN\x10\x00\x12\x18\n\x14PROVIDER_CODE_OPENAI\x10\x01\x12\x18\n\x14PROVIDER_CODE_TONGYI\x10\x02\x12\x19\n\x15PROVIDER_CODE_ZHIPUAI\x10\x03\x12\x16\n\x12PROVIDER_CODE_GROK\x10\x04\x12\x1a\n\x16PROVIDER_CODE_DEEPSEEK\x10\x05*q\n\x12ProviderStatusEnum\x12\x1b\n\x17PROVIDER_STATUS_UNKNOWN\x10\x00\x12\x1f\n\x1bPROVIDER_STATUS_UNAVAILABLE\x10\x01\x12\x1d\n\x19PROVIDER_STATUS_AVAILABLE\x10\x02*g\n\rQuotaTypeEnum\x12\x16\n\x12QUOTA_TYPE_UNKNOWN\x10\x00\x12\x13\n\x0fQUOTA_TYPE_PAID\x10\x01\x12\x13\n\x0fQUOTA_TYPE_FREE\x10\x02\x12\x14\n\x10QUOTA_TYPE_TRIAL\x10\x03\x32\xb5\x04\n\x08Provider\x12k\n\x0c\x44\x65scriptions\x12+.yeying.api.llm.ProviderDescriptionsRequest\x1a,.yeying.api.llm.ProviderDescriptionsResponse"\x00\x12Y\n\x06Models\x12%.yeying.api.llm.ProviderModelsRequest\x1a&.yeying.api.llm.ProviderModelsResponse"\x00\x12Y\n\x06Search\x12%.yeying.api.llm.SearchProviderRequest\x1a&.yeying.api.llm.SearchProviderResponse"\x00\x12Y\n\x06\x44\x65tail\x12%.yeying.api.llm.ProviderDetailRequest\x1a&.yeying.api.llm.ProviderDetailResponse"\x00\x12P\n\x03\x41\x64\x64\x12".yeying.api.llm.AddProviderRequest\x1a#.yeying.api.llm.AddProviderResponse"\x00\x12Y\n\x06\x44\x65lete\x12%.yeying.api.llm.DeleteProviderRequest\x1a&.yeying.api.llm.DeleteProviderResponse"\x00\x42\x10Z\x0eyeying/api/llmb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.llm.provider_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\016yeying/api/llm"
    _globals["_MODELTYPEENUM"]._serialized_start = 3805
    _globals["_MODELTYPEENUM"]._serialized_end = 4020
    _globals["_MODELFEATUREENUM"]._serialized_start = 4023
    _globals["_MODELFEATUREENUM"]._serialized_end = 4278
    _globals["_PROVIDERCODEENUM"]._serialized_start = 4281
    _globals["_PROVIDERCODEENUM"]._serialized_end = 4457
    _globals["_PROVIDERSTATUSENUM"]._serialized_start = 4459
    _globals["_PROVIDERSTATUSENUM"]._serialized_end = 4572
    _globals["_QUOTATYPEENUM"]._serialized_start = 4574
    _globals["_QUOTATYPEENUM"]._serialized_end = 4677
    _globals["_PROVIDERDESCRIPTIONSREQUEST"]._serialized_start = 82
    _globals["_PROVIDERDESCRIPTIONSREQUEST"]._serialized_end = 161
    _globals["_PROVIDERDESCRIPTIONSRESPONSE"]._serialized_start = 164
    _globals["_PROVIDERDESCRIPTIONSRESPONSE"]._serialized_end = 308
    _globals["_PROVIDERDESCRIPTIONSRESPONSEBODY"]._serialized_start = 311
    _globals["_PROVIDERDESCRIPTIONSRESPONSEBODY"]._serialized_end = 455
    _globals["_PROVIDERMODELSREQUEST"]._serialized_start = 458
    _globals["_PROVIDERMODELSREQUEST"]._serialized_end = 588
    _globals["_PROVIDERMODELSREQUESTBODY"]._serialized_start = 590
    _globals["_PROVIDERMODELSREQUESTBODY"]._serialized_end = 715
    _globals["_PROVIDERMODELSRESPONSE"]._serialized_start = 718
    _globals["_PROVIDERMODELSRESPONSE"]._serialized_end = 850
    _globals["_PROVIDERMODELSRESPONSEBODY"]._serialized_start = 852
    _globals["_PROVIDERMODELSRESPONSEBODY"]._serialized_end = 978
    _globals["_DELETEPROVIDERREQUEST"]._serialized_start = 981
    _globals["_DELETEPROVIDERREQUEST"]._serialized_end = 1111
    _globals["_DELETEPROVIDERREQUESTBODY"]._serialized_start = 1113
    _globals["_DELETEPROVIDERREQUESTBODY"]._serialized_end = 1153
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_start = 1156
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_end = 1288
    _globals["_DELETEPROVIDERRESPONSEBODY"]._serialized_start = 1290
    _globals["_DELETEPROVIDERRESPONSEBODY"]._serialized_end = 1369
    _globals["_SEARCHPROVIDERREQUEST"]._serialized_start = 1372
    _globals["_SEARCHPROVIDERREQUEST"]._serialized_end = 1502
    _globals["_SEARCHPROVIDERREQUESTBODY"]._serialized_start = 1505
    _globals["_SEARCHPROVIDERREQUESTBODY"]._serialized_end = 1638
    _globals["_SEARCHPROVIDERRESPONSE"]._serialized_start = 1641
    _globals["_SEARCHPROVIDERRESPONSE"]._serialized_end = 1773
    _globals["_SEARCHPROVIDERRESPONSEBODY"]._serialized_start = 1776
    _globals["_SEARCHPROVIDERRESPONSEBODY"]._serialized_end = 1908
    _globals["_ADDPROVIDERREQUEST"]._serialized_start = 1910
    _globals["_ADDPROVIDERREQUEST"]._serialized_end = 2034
    _globals["_ADDPROVIDERREQUESTBODY"]._serialized_start = 2036
    _globals["_ADDPROVIDERREQUESTBODY"]._serialized_end = 2112
    _globals["_ADDPROVIDERRESPONSE"]._serialized_start = 2114
    _globals["_ADDPROVIDERRESPONSE"]._serialized_end = 2240
    _globals["_ADDPROVIDERRESPONSEBODY"]._serialized_start = 2243
    _globals["_ADDPROVIDERRESPONSEBODY"]._serialized_end = 2371
    _globals["_PROVIDERDETAILREQUEST"]._serialized_start = 2374
    _globals["_PROVIDERDETAILREQUEST"]._serialized_end = 2504
    _globals["_PROVIDERDETAILREQUESTBODY"]._serialized_start = 2506
    _globals["_PROVIDERDETAILREQUESTBODY"]._serialized_end = 2546
    _globals["_PROVIDERDETAILRESPONSE"]._serialized_start = 2549
    _globals["_PROVIDERDETAILRESPONSE"]._serialized_end = 2681
    _globals["_PROVIDERDETAILRESPONSEBODY"]._serialized_start = 2683
    _globals["_PROVIDERDETAILRESPONSEBODY"]._serialized_end = 2810
    _globals["_PROVIDERDETAIL"]._serialized_start = 2812
    _globals["_PROVIDERDETAIL"]._serialized_end = 2926
    _globals["_PROVIDERDESCRIPTION"]._serialized_start = 2929
    _globals["_PROVIDERDESCRIPTION"]._serialized_end = 3109
    _globals["_SEARCHPROVIDERCONDITION"]._serialized_start = 3111
    _globals["_SEARCHPROVIDERCONDITION"]._serialized_end = 3184
    _globals["_PROVIDERMETADATA"]._serialized_start = 3187
    _globals["_PROVIDERMETADATA"]._serialized_end = 3438
    _globals["_MODELMETADATA"]._serialized_start = 3441
    _globals["_MODELMETADATA"]._serialized_end = 3623
    _globals["_PROVIDERSTATE"]._serialized_start = 3626
    _globals["_PROVIDERSTATE"]._serialized_end = 3802
    _globals["_PROVIDER"]._serialized_start = 4680
    _globals["_PROVIDER"]._serialized_end = 5245
# @@protoc_insertion_point(module_scope)



from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationMetadata(_message.Message):
    __slots__ = (
        "owner",
        "network",
        "address",
        "did",
        "version",
        "hash",
        "name",
        "code",
        "description",
        "location",
        "serviceCodes",
        "avatar",
        "createdAt",
        "updatedAt",
        "signature",
        "codePackagePath",
    )
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    SERVICECODES_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    CODEPACKAGEPATH_FIELD_NUMBER: _ClassVar[int]
    owner: str
    network: str
    address: str
    did: str
    version: int
    hash: str
    name: str
    code: _code_pb2.ApplicationCodeEnum
    description: str
    location: str
    serviceCodes: _containers.RepeatedScalarFieldContainer[_code_pb2.ServiceCodeEnum]
    avatar: str
    createdAt: str
    updatedAt: str
    signature: str
    codePackagePath: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        network: _Optional[str] = ...,
        address: _Optional[str] = ...,
        did: _Optional[str] = ...,
        version: _Optional[int] = ...,
        hash: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[_Union[_code_pb2.ApplicationCodeEnum, str]] = ...,
        description: _Optional[str] = ...,
        location: _Optional[str] = ...,
        serviceCodes: _Optional[_Iterable[_Union[_code_pb2.ServiceCodeEnum, str]]] = ...,
        avatar: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
        codePackagePath: _Optional[str] = ...,
    ) -> None: ...

class ServiceMetadata(_message.Message):
    __slots__ = (
        "owner",
        "network",
        "address",
        "did",
        "version",
        "name",
        "description",
        "code",
        "apiCodes",
        "proxy",
        "grpc",
        "avatar",
        "createdAt",
        "updatedAt",
        "signature",
        "codePackagePath",
    )
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    APICODES_FIELD_NUMBER: _ClassVar[int]
    PROXY_FIELD_NUMBER: _ClassVar[int]
    GRPC_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    CODEPACKAGEPATH_FIELD_NUMBER: _ClassVar[int]
    owner: str
    network: str
    address: str
    did: str
    version: int
    name: str
    description: str
    code: _code_pb2.ServiceCodeEnum
    apiCodes: _containers.RepeatedScalarFieldContainer[_code_pb2.ApiCodeEnum]
    proxy: str
    grpc: str
    avatar: str
    createdAt: str
    updatedAt: str
    signature: str
    codePackagePath: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        network: _Optional[str] = ...,
        address: _Optional[str] = ...,
        did: _Optional[str] = ...,
        version: _Optional[int] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        code: _Optional[_Union[_code_pb2.ServiceCodeEnum, str]] = ...,
        apiCodes: _Optional[_Iterable[_Union[_code_pb2.ApiCodeEnum, str]]] = ...,
        proxy: _Optional[str] = ...,
        grpc: _Optional[str] = ...,
        avatar: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
        codePackagePath: _Optional[str] = ...,
    ) -> None: ...

class StateMetadata(_message.Message):
    __slots__ = ("did", "version", "status", "signature", "createdAt", "updatedAt", "type")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    status: _code_pb2.ApplicationStatusEnum
    signature: str
    createdAt: str
    updatedAt: str
    type: _code_pb2.AuditTypeEnum
    def __init__(
        self,
        did: _Optional[str] = ...,
        version: _Optional[int] = ...,
        status: _Optional[_Union[_code_pb2.ApplicationStatusEnum, str]] = ...,
        signature: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        type: _Optional[_Union[_code_pb2.AuditTypeEnum, str]] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.contract import contract_pb2 as yeying_dot_api_dot_contract_dot_contract__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/contract/contract_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class WalletStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.createAddress = channel.unary_unary(
            "/Wallet/createAddress",
            request_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressResponse.FromString,
            _registered_method=True,
        )
        self.transaction = channel.unary_unary(
            "/Wallet/transaction",
            request_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.TransactionRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.TransactionResponse.FromString,
            _registered_method=True,
        )
        self.balance = channel.unary_unary(
            "/Wallet/balance",
            request_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.BalanceRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.BalanceResponse.FromString,
            _registered_method=True,
        )
        self.walletInfo = channel.unary_unary(
            "/Wallet/walletInfo",
            request_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoResponse.FromString,
            _registered_method=True,
        )


class WalletServicer(object):
    """Missing associated documentation comment in .proto file."""

    def createAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def transaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def balance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def walletInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WalletServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "createAddress": grpc.unary_unary_rpc_method_handler(
            servicer.createAddress,
            request_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressRequest.FromString,
            response_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressResponse.SerializeToString,
        ),
        "transaction": grpc.unary_unary_rpc_method_handler(
            servicer.transaction,
            request_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.TransactionRequest.FromString,
            response_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.TransactionResponse.SerializeToString,
        ),
        "balance": grpc.unary_unary_rpc_method_handler(
            servicer.balance,
            request_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.BalanceRequest.FromString,
            response_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.BalanceResponse.SerializeToString,
        ),
        "walletInfo": grpc.unary_unary_rpc_method_handler(
            servicer.walletInfo,
            request_deserializer=yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoRequest.FromString,
            response_serializer=yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("Wallet", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("Wallet", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Wallet(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def createAddress(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Wallet/createAddress",
            yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressRequest.SerializeToString,
            yeying_dot_api_dot_contract_dot_contract__pb2.CreateAddressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def transaction(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Wallet/transaction",
            yeying_dot_api_dot_contract_dot_contract__pb2.TransactionRequest.SerializeToString,
            yeying_dot_api_dot_contract_dot_contract__pb2.TransactionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def balance(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Wallet/balance",
            yeying_dot_api_dot_contract_dot_contract__pb2.BalanceRequest.SerializeToString,
            yeying_dot_api_dot_contract_dot_contract__pb2.BalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def walletInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Wallet/walletInfo",
            yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoRequest.SerializeToString,
            yeying_dot_api_dot_contract_dot_contract__pb2.WalletInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by protobuf_init. Do not edit manually.
from .asset_pb2 import SearchAssetRequest
from .asset_pb2 import SearchAssetRequestBody
from .asset_pb2 import SearchAssetCondition
from .asset_pb2 import SearchAssetResponse
from .asset_pb2 import SearchAssetResponseBody
from .asset_pb2 import SignAssetRequest
from .asset_pb2 import SignAssetRequestBody
from .asset_pb2 import SignAssetResponse
from .asset_pb2 import SignAssetResponseBody
from .asset_pb2 import UpdateAssetRequest
from .asset_pb2 import UpdateAssetRequestBody
from .asset_pb2 import UpdateAssetResponse
from .asset_pb2 import UpdateAssetResponseBody
from .asset_pb2 import AssetDetailRequest
from .asset_pb2 import AssetDetailRequestBody
from .asset_pb2 import AssetDetailResponse
from .asset_pb2 import AssetDetailResponseBody
from .asset_pb2 import DeleteAssetRequest
from .asset_pb2 import DeleteAssetRequestBody
from .asset_pb2 import DeleteAssetResponse
from .asset_pb2 import DeleteAssetResponseBody
from .asset_pb2 import AssetMetadata
from .asset_pb2_grpc import AssetServicer
from .asset_pb2_grpc import AssetStub
from .asset_pb2_grpc import add_AssetServicer_to_server
from .asset_pb2_grpc import Asset
from .block_pb2 import ConfirmBlockRequest
from .block_pb2 import ConfirmBlockRequestBody
from .block_pb2 import ConfirmBlockResponse
from .block_pb2 import ConfirmBlockResponseBody
from .block_pb2 import StreamPutBlockRequest
from .block_pb2 import StreamPutBlockRequestHead
from .block_pb2 import StreamPutBlockRequestHeadBody
from .block_pb2 import StreamPutBlockRequestBody
from .block_pb2 import StreamPutBlockRequestTail
from .block_pb2 import StreamPutBlockResponse
from .block_pb2 import StreamPutBlockResponseHead
from .block_pb2 import StreamPutBlockResponseHeadBody
from .block_pb2 import StreamPutBlockResponseTail
from .block_pb2 import StreamPutBlockResponseTailBody
from .block_pb2 import PutBlockRequest
from .block_pb2 import PutBlockRequestBody
from .block_pb2 import PutBlockResponse
from .block_pb2 import PutBlockResponseBody
from .block_pb2 import GetBlockRequest
from .block_pb2 import GetBlockRequestBody
from .block_pb2 import StreamGetBlockRequest
from .block_pb2 import StreamGetBlockRequestHead
from .block_pb2 import StreamGetBlockRequestHeadBody
from .block_pb2 import StreamGetBlockRequestBody
from .block_pb2 import StreamGetBlockResponse
from .block_pb2 import StreamGetBlockResponseHead
from .block_pb2 import StreamGetBlockResponseHeadBody
from .block_pb2 import StreamGetBlockResponseBody
from .block_pb2 import StreamGetBlockResponseTail
from .block_pb2 import StreamGetBlockResponseTailBody
from .block_pb2 import GetBlockResponseBody
from .block_pb2 import GetBlockResponse
from .block_pb2 import BlockMetadata
from .block_pb2_grpc import BlockServicer
from .block_pb2_grpc import BlockStub
from .block_pb2_grpc import add_BlockServicer_to_server
from .block_pb2_grpc import Block
from .link_pb2 import CreateLinkRequest
from .link_pb2 import CreateLinkRequestBody
from .link_pb2 import CreateLinkResponse
from .link_pb2 import CreateLinkResponseBody
from .link_pb2 import SearchLinkRequest
from .link_pb2 import SearchLinkRequestBody
from .link_pb2 import SearchLinkCondition
from .link_pb2 import SearchLinkResponse
from .link_pb2 import SearchLinkResponseBody
from .link_pb2 import DisableLinkRequest
from .link_pb2 import DisableLinkRequestBody
from .link_pb2 import DisableLinkResponse
from .link_pb2 import DisableLinkResponseBody
from .link_pb2 import UpdateLinkRequest
from .link_pb2 import UpdateLinkRequestBody
from .link_pb2 import UpdateLinkResponse
from .link_pb2 import UpdateLinkResponseBody
from .link_pb2 import LinkDetailRequest
from .link_pb2 import LinkDetailRequestBody
from .link_pb2 import LinkDetailResponse
from .link_pb2 import LinkDetailResponseBody
from .link_pb2 import LinkDetail
from .link_pb2 import LinkVisitorRequest
from .link_pb2 import LinkVisitorRequestBody
from .link_pb2 import LinkVisitorResponse
from .link_pb2 import LinkVisitorResponseBody
from .link_pb2 import LinkMetadata
from .link_pb2 import UrlMetadata
from .link_pb2 import VisitorMetadata
from .link_pb2 import UrlStatusEnum
from .link_pb2 import LinkTypeEnum
from .link_pb2_grpc import LinkServicer
from .link_pb2_grpc import LinkStub
from .link_pb2_grpc import add_LinkServicer_to_server
from .link_pb2_grpc import Link
from .namespace_pb2 import SearchNamespaceRequest
from .namespace_pb2 import SearchNamespaceRequestBody
from .namespace_pb2 import SearchNamespaceCondition
from .namespace_pb2 import NamespaceDetailRequest
from .namespace_pb2 import NamespaceDetailRequestBody
from .namespace_pb2 import NamespaceDetailResponse
from .namespace_pb2 import NamespaceDetailResponseBody
from .namespace_pb2 import SearchNamespaceResponse
from .namespace_pb2 import SearchNamespaceResponseBody
from .namespace_pb2 import CreateNamespaceRequest
from .namespace_pb2 import CreateNamespaceRequestBody
from .namespace_pb2 import CreateNamespaceResponse
from .namespace_pb2 import CreateNamespaceResponseBody
from .namespace_pb2 import UpdateNamespaceRequest
from .namespace_pb2 import UpdateNamespaceRequestBody
from .namespace_pb2 import UpdateNamespaceResponse
from .namespace_pb2 import UpdateNamespaceResponseBody
from .namespace_pb2 import DeleteNamespaceRequest
from .namespace_pb2 import DeleteNamespaceRequestBody
from .namespace_pb2 import DeleteNamespaceResponse
from .namespace_pb2 import DeleteNamespaceResponseBody
from .namespace_pb2 import NamespaceMetadata
from .namespace_pb2_grpc import NamespaceServicer
from .namespace_pb2_grpc import NamespaceStub
from .namespace_pb2_grpc import add_NamespaceServicer_to_server
from .namespace_pb2_grpc import Namespace
from .recycle_pb2 import SearchDeletedAssetRequest
from .recycle_pb2 import SearchDeletedAssetRequestBody
from .recycle_pb2 import SearchDeletedAssetResponse
from .recycle_pb2 import SearchDeletedAssetResponseBody
from .recycle_pb2 import RecoverDeletedAssetRequest
from .recycle_pb2 import RecoverDeletedAssetRequestBody
from .recycle_pb2 import RecoverDeletedAssetResponse
from .recycle_pb2 import RecoverDeletedAssetResponseBody
from .recycle_pb2 import RemoveDeletedAssetRequest
from .recycle_pb2 import RemoveDeletedAssetRequestBody
from .recycle_pb2 import RemoveDeletedAssetResponse
from .recycle_pb2 import RemoveDeletedAssetResponseBody
from .recycle_pb2 import DeletedAssetMetadata
from .recycle_pb2_grpc import RecycleServicer
from .recycle_pb2_grpc import RecycleStub
from .recycle_pb2_grpc import add_RecycleServicer_to_server
from .recycle_pb2_grpc import Recycle



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.apps.zuoyepigai import imagecontent_pb2 as _imagecontent_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class AssignmentUploadRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentUploadRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentUploadRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentUploadRequestBody(_message.Message):
    __slots__ = ("did", "fileUrl", "taskUid", "type", "subject", "testPaperName")
    DID_FIELD_NUMBER: _ClassVar[int]
    FILEURL_FIELD_NUMBER: _ClassVar[int]
    TASKUID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    TESTPAPERNAME_FIELD_NUMBER: _ClassVar[int]
    did: str
    fileUrl: _containers.RepeatedScalarFieldContainer[str]
    taskUid: str
    type: _imagecontent_pb2.ImageContentTypeEnum
    subject: str
    testPaperName: str
    def __init__(
        self,
        did: _Optional[str] = ...,
        fileUrl: _Optional[_Iterable[str]] = ...,
        taskUid: _Optional[str] = ...,
        type: _Optional[_Union[_imagecontent_pb2.ImageContentTypeEnum, str]] = ...,
        subject: _Optional[str] = ...,
        testPaperName: _Optional[str] = ...,
    ) -> None: ...

class AssignmentUploadResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentUploadResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentUploadResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentUploadResponseBody(_message.Message):
    __slots__ = ("status", "result")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    result: str
    def __init__(
        self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., result: _Optional[str] = ...
    ) -> None: ...

class AssignmentBigModelRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentBigModelRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentBigModelRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentBigModelRequestBody(_message.Message):
    __slots__ = ("question",)
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    question: str
    def __init__(self, question: _Optional[str] = ...) -> None: ...

class AssignmentBigModelResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentBigModelResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentBigModelResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentBigModelResponseBody(_message.Message):
    __slots__ = ("status", "result")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    result: str
    def __init__(
        self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., result: _Optional[str] = ...
    ) -> None: ...

class AssignmentArtificialRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentArtificialRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentArtificialRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentArtificialRequestBody(_message.Message):
    __slots__ = ("fileUrl",)
    FILEURL_FIELD_NUMBER: _ClassVar[int]
    fileUrl: str
    def __init__(self, fileUrl: _Optional[str] = ...) -> None: ...

class AssignmentArtificialResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentArtificialResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentArtificialResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentArtificialResponseBody(_message.Message):
    __slots__ = ("status", "result")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    result: str
    def __init__(
        self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., result: _Optional[str] = ...
    ) -> None: ...

class StudentActionRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StudentActionRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StudentActionRequestBody, _Mapping]] = ...,
    ) -> None: ...

class StudentActionRequestBody(_message.Message):
    __slots__ = ("taskUid", "did", "action")
    TASKUID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    taskUid: str
    did: str
    action: str
    def __init__(
        self, taskUid: _Optional[str] = ..., did: _Optional[str] = ..., action: _Optional[str] = ...
    ) -> None: ...

class StudentActionResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: StudentActionResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[StudentActionResponseBody, _Mapping]] = ...,
    ) -> None: ...

class StudentActionResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class AssignmentCorrectionRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentCorrectionRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentCorrectionRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentCorrectionRequestBody(_message.Message):
    __slots__ = ("qa",)
    QA_FIELD_NUMBER: _ClassVar[int]
    qa: str
    def __init__(self, qa: _Optional[str] = ...) -> None: ...

class AssignmentCorrectionResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AssignmentCorrectionResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AssignmentCorrectionResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AssignmentCorrectionResponseBody(_message.Message):
    __slots__ = ("status", "result")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    result: str
    def __init__(
        self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ..., result: _Optional[str] = ...
    ) -> None: ...



# -*- coding:utf-8 -*-
import re

from yeying.client.model.option import ProviderOption
from yeying.client.tool.authenticate import Authenticate
from yeying.client.utils import log_utils

log = log_utils.get_logger(__name__)


class BaseProvider(object):

    def __init__(self, **kw):
        """
        获取 api 地址
        :param kw:option: ProviderOption
        """
        self.option: ProviderOption = kw.get("option")
        self.option.proxy = re.sub(r'^https?://', '', self.option.proxy)
        self.authenticate: Authenticate = Authenticate(self.option.block_address)



from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MessageHeader(_message.Message):
    __slots__ = ("did", "authType", "authContent", "nonce", "timestamp", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    AUTHTYPE_FIELD_NUMBER: _ClassVar[int]
    AUTHCONTENT_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    authType: _code_pb2.AuthenticateTypeEnum
    authContent: str
    nonce: str
    timestamp: str
    version: int
    def __init__(
        self,
        did: _Optional[str] = ...,
        authType: _Optional[_Union[_code_pb2.AuthenticateTypeEnum, str]] = ...,
        authContent: _Optional[str] = ...,
        nonce: _Optional[str] = ...,
        timestamp: _Optional[str] = ...,
        version: _Optional[int] = ...,
    ) -> None: ...

class ResponseStatus(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: _code_pb2.ResponseCodeEnum
    message: str
    def __init__(
        self, code: _Optional[_Union[_code_pb2.ResponseCodeEnum, str]] = ..., message: _Optional[str] = ...
    ) -> None: ...

class ResponsePage(_message.Message):
    __slots__ = ("total", "page", "pageSize")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    total: int
    page: int
    pageSize: int
    def __init__(
        self, total: _Optional[int] = ..., page: _Optional[int] = ..., pageSize: _Optional[int] = ...
    ) -> None: ...

class RequestPage(_message.Message):
    __slots__ = ("page", "pageSize")
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    page: int
    pageSize: int
    def __init__(self, page: _Optional[int] = ..., pageSize: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/group.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/group.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&yeying/api/apps/zuoyepigai/group.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x82\x01\n\x0f\x41\x64\x64GroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.AddGroupRequestBody"N\n\x13\x41\x64\x64GroupRequestBody\x12\x37\n\x04meta\x18\x01 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x84\x01\n\x10\x41\x64\x64GroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.AddGroupResponseBody"\x82\x01\n\x14\x41\x64\x64GroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x88\x01\n\x12\x44\x65tailGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DetailGroupRequestBody"%\n\x16\x44\x65tailGroupRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8a\x01\n\x13\x44\x65tailGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.DetailGroupResponseBody"\xc5\x01\n\x17\x44\x65tailGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData\x12>\n\x0bstudentList\x18\x03 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x84\x01\n\x10ListGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.ListGroupRequestBody"\x89\x01\n\x14ListGroupRequestBody\x12\x12\n\nteacherDid\x18\x01 \x01(\t\x12.\n\tpageIndex\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x86\x01\n\x11ListGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.ListGroupResponseBody"\x92\x01\n\x15ListGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData\x12\r\n\x05total\x18\x03 \x01(\x04"\x88\x01\n\x12UpdateGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.UpdateGroupRequestBody"Q\n\x16UpdateGroupRequestBody\x12\x37\n\x04meta\x18\x01 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x8a\x01\n\x13UpdateGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.UpdateGroupResponseBody"\x85\x01\n\x17UpdateGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x88\x01\n\x12\x44\x65leteGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DeleteGroupRequestBody"%\n\x16\x44\x65leteGroupRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8a\x01\n\x13\x44\x65leteGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.DeleteGroupResponseBody"\x85\x01\n\x17\x44\x65leteGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData2\x99\x04\n\x05Group\x12\x62\n\x03\x41\x64\x64\x12+.yeying.api.apps.zuoyepigai.AddGroupRequest\x1a,.yeying.api.apps.zuoyepigai.AddGroupResponse"\x00\x12k\n\x06\x44\x65tail\x12..yeying.api.apps.zuoyepigai.DetailGroupRequest\x1a/.yeying.api.apps.zuoyepigai.DetailGroupResponse"\x00\x12\x65\n\x04List\x12,.yeying.api.apps.zuoyepigai.ListGroupRequest\x1a-.yeying.api.apps.zuoyepigai.ListGroupResponse"\x00\x12k\n\x06Update\x12..yeying.api.apps.zuoyepigai.UpdateGroupRequest\x1a/.yeying.api.apps.zuoyepigai.UpdateGroupResponse"\x00\x12k\n\x06\x44\x65lete\x12..yeying.api.apps.zuoyepigai.DeleteGroupRequest\x1a/.yeying.api.apps.zuoyepigai.DeleteGroupResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.group_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDGROUPREQUEST"]._serialized_start = 175
    _globals["_ADDGROUPREQUEST"]._serialized_end = 305
    _globals["_ADDGROUPREQUESTBODY"]._serialized_start = 307
    _globals["_ADDGROUPREQUESTBODY"]._serialized_end = 385
    _globals["_ADDGROUPRESPONSE"]._serialized_start = 388
    _globals["_ADDGROUPRESPONSE"]._serialized_end = 520
    _globals["_ADDGROUPRESPONSEBODY"]._serialized_start = 523
    _globals["_ADDGROUPRESPONSEBODY"]._serialized_end = 653
    _globals["_DETAILGROUPREQUEST"]._serialized_start = 656
    _globals["_DETAILGROUPREQUEST"]._serialized_end = 792
    _globals["_DETAILGROUPREQUESTBODY"]._serialized_start = 794
    _globals["_DETAILGROUPREQUESTBODY"]._serialized_end = 831
    _globals["_DETAILGROUPRESPONSE"]._serialized_start = 834
    _globals["_DETAILGROUPRESPONSE"]._serialized_end = 972
    _globals["_DETAILGROUPRESPONSEBODY"]._serialized_start = 975
    _globals["_DETAILGROUPRESPONSEBODY"]._serialized_end = 1172
    _globals["_LISTGROUPREQUEST"]._serialized_start = 1175
    _globals["_LISTGROUPREQUEST"]._serialized_end = 1307
    _globals["_LISTGROUPREQUESTBODY"]._serialized_start = 1310
    _globals["_LISTGROUPREQUESTBODY"]._serialized_end = 1447
    _globals["_LISTGROUPRESPONSE"]._serialized_start = 1450
    _globals["_LISTGROUPRESPONSE"]._serialized_end = 1584
    _globals["_LISTGROUPRESPONSEBODY"]._serialized_start = 1587
    _globals["_LISTGROUPRESPONSEBODY"]._serialized_end = 1733
    _globals["_UPDATEGROUPREQUEST"]._serialized_start = 1736
    _globals["_UPDATEGROUPREQUEST"]._serialized_end = 1872
    _globals["_UPDATEGROUPREQUESTBODY"]._serialized_start = 1874
    _globals["_UPDATEGROUPREQUESTBODY"]._serialized_end = 1955
    _globals["_UPDATEGROUPRESPONSE"]._serialized_start = 1958
    _globals["_UPDATEGROUPRESPONSE"]._serialized_end = 2096
    _globals["_UPDATEGROUPRESPONSEBODY"]._serialized_start = 2099
    _globals["_UPDATEGROUPRESPONSEBODY"]._serialized_end = 2232
    _globals["_DELETEGROUPREQUEST"]._serialized_start = 2235
    _globals["_DELETEGROUPREQUEST"]._serialized_end = 2371
    _globals["_DELETEGROUPREQUESTBODY"]._serialized_start = 2373
    _globals["_DELETEGROUPREQUESTBODY"]._serialized_end = 2410
    _globals["_DELETEGROUPRESPONSE"]._serialized_start = 2413
    _globals["_DELETEGROUPRESPONSE"]._serialized_end = 2551
    _globals["_DELETEGROUPRESPONSEBODY"]._serialized_start = 2554
    _globals["_DELETEGROUPRESPONSEBODY"]._serialized_end = 2687
    _globals["_GROUP"]._serialized_start = 2690
    _globals["_GROUP"]._serialized_end = 3227
# @@protoc_insertion_point(module_scope)



# -*- coding:utf-8 -*-
from yeying.api.web3 import BlockAddress


class ProviderOption(object):

    def __init__(self, proxy: str, block_address: BlockAddress):
        self.proxy = proxy
        self.block_address: BlockAddress = block_address



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/assignment.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/assignment.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import imagecontent_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_imagecontent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n+yeying/api/apps/zuoyepigai/assignment.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a-yeying/api/apps/zuoyepigai/imagecontent.proto"\x92\x01\n\x17\x41ssignmentUploadRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x45\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x37.yeying.api.apps.zuoyepigai.AssignmentUploadRequestBody"\xb4\x01\n\x1b\x41ssignmentUploadRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07\x66ileUrl\x18\x02 \x03(\t\x12\x0f\n\x07taskUid\x18\x03 \x01(\t\x12>\n\x04type\x18\x04 \x01(\x0e\x32\x30.yeying.api.apps.zuoyepigai.ImageContentTypeEnum\x12\x0f\n\x07subject\x18\x05 \x01(\t\x12\x15\n\rtestPaperName\x18\x06 \x01(\t"\x94\x01\n\x18\x41ssignmentUploadResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x46\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x38.yeying.api.apps.zuoyepigai.AssignmentUploadResponseBody"a\n\x1c\x41ssignmentUploadResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06result\x18\x02 \x01(\t"\x96\x01\n\x19\x41ssignmentBigModelRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12G\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x39.yeying.api.apps.zuoyepigai.AssignmentBigModelRequestBody"1\n\x1d\x41ssignmentBigModelRequestBody\x12\x10\n\x08question\x18\x01 \x01(\t"\x98\x01\n\x1a\x41ssignmentBigModelResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12H\n\x04\x62ody\x18\x02 \x01(\x0b\x32:.yeying.api.apps.zuoyepigai.AssignmentBigModelResponseBody"c\n\x1e\x41ssignmentBigModelResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06result\x18\x02 \x01(\t"\x9a\x01\n\x1b\x41ssignmentArtificialRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12I\n\x04\x62ody\x18\x02 \x01(\x0b\x32;.yeying.api.apps.zuoyepigai.AssignmentArtificialRequestBody"2\n\x1f\x41ssignmentArtificialRequestBody\x12\x0f\n\x07\x66ileUrl\x18\x01 \x01(\t"\x9c\x01\n\x1c\x41ssignmentArtificialResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12J\n\x04\x62ody\x18\x02 \x01(\x0b\x32<.yeying.api.apps.zuoyepigai.AssignmentArtificialResponseBody"e\n AssignmentArtificialResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06result\x18\x02 \x01(\t"\x8c\x01\n\x14StudentActionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.StudentActionRequestBody"H\n\x18StudentActionRequestBody\x12\x0f\n\x07taskUid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t"\x8e\x01\n\x15StudentActionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.StudentActionResponseBody"N\n\x19StudentActionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x9a\x01\n\x1b\x41ssignmentCorrectionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12I\n\x04\x62ody\x18\x02 \x01(\x0b\x32;.yeying.api.apps.zuoyepigai.AssignmentCorrectionRequestBody"-\n\x1f\x41ssignmentCorrectionRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x9c\x01\n\x1c\x41ssignmentCorrectionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12J\n\x04\x62ody\x18\x02 \x01(\x0b\x32<.yeying.api.apps.zuoyepigai.AssignmentCorrectionResponseBody"e\n AssignmentCorrectionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06result\x18\x02 \x01(\t2\x91\x05\n\nAssignment\x12u\n\x06Upload\x12\x33.yeying.api.apps.zuoyepigai.AssignmentUploadRequest\x1a\x34.yeying.api.apps.zuoyepigai.AssignmentUploadResponse"\x00\x12\x83\x01\n\x10\x42igModelGenerate\x12\x35.yeying.api.apps.zuoyepigai.AssignmentBigModelRequest\x1a\x36.yeying.api.apps.zuoyepigai.AssignmentBigModelResponse"\x00\x12\x89\x01\n\x12\x41rtificialGenerate\x12\x37.yeying.api.apps.zuoyepigai.AssignmentArtificialRequest\x1a\x38.yeying.api.apps.zuoyepigai.AssignmentArtificialResponse"\x00\x12v\n\rStudentAction\x12\x30.yeying.api.apps.zuoyepigai.StudentActionRequest\x1a\x31.yeying.api.apps.zuoyepigai.StudentActionResponse"\x00\x12\x81\x01\n\nCorrection\x12\x37.yeying.api.apps.zuoyepigai.AssignmentCorrectionRequest\x1a\x38.yeying.api.apps.zuoyepigai.AssignmentCorrectionResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.assignment_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ASSIGNMENTUPLOADREQUEST"]._serialized_start = 156
    _globals["_ASSIGNMENTUPLOADREQUEST"]._serialized_end = 302
    _globals["_ASSIGNMENTUPLOADREQUESTBODY"]._serialized_start = 305
    _globals["_ASSIGNMENTUPLOADREQUESTBODY"]._serialized_end = 485
    _globals["_ASSIGNMENTUPLOADRESPONSE"]._serialized_start = 488
    _globals["_ASSIGNMENTUPLOADRESPONSE"]._serialized_end = 636
    _globals["_ASSIGNMENTUPLOADRESPONSEBODY"]._serialized_start = 638
    _globals["_ASSIGNMENTUPLOADRESPONSEBODY"]._serialized_end = 735
    _globals["_ASSIGNMENTBIGMODELREQUEST"]._serialized_start = 738
    _globals["_ASSIGNMENTBIGMODELREQUEST"]._serialized_end = 888
    _globals["_ASSIGNMENTBIGMODELREQUESTBODY"]._serialized_start = 890
    _globals["_ASSIGNMENTBIGMODELREQUESTBODY"]._serialized_end = 939
    _globals["_ASSIGNMENTBIGMODELRESPONSE"]._serialized_start = 942
    _globals["_ASSIGNMENTBIGMODELRESPONSE"]._serialized_end = 1094
    _globals["_ASSIGNMENTBIGMODELRESPONSEBODY"]._serialized_start = 1096
    _globals["_ASSIGNMENTBIGMODELRESPONSEBODY"]._serialized_end = 1195
    _globals["_ASSIGNMENTARTIFICIALREQUEST"]._serialized_start = 1198
    _globals["_ASSIGNMENTARTIFICIALREQUEST"]._serialized_end = 1352
    _globals["_ASSIGNMENTARTIFICIALREQUESTBODY"]._serialized_start = 1354
    _globals["_ASSIGNMENTARTIFICIALREQUESTBODY"]._serialized_end = 1404
    _globals["_ASSIGNMENTARTIFICIALRESPONSE"]._serialized_start = 1407
    _globals["_ASSIGNMENTARTIFICIALRESPONSE"]._serialized_end = 1563
    _globals["_ASSIGNMENTARTIFICIALRESPONSEBODY"]._serialized_start = 1565
    _globals["_ASSIGNMENTARTIFICIALRESPONSEBODY"]._serialized_end = 1666
    _globals["_STUDENTACTIONREQUEST"]._serialized_start = 1669
    _globals["_STUDENTACTIONREQUEST"]._serialized_end = 1809
    _globals["_STUDENTACTIONREQUESTBODY"]._serialized_start = 1811
    _globals["_STUDENTACTIONREQUESTBODY"]._serialized_end = 1883
    _globals["_STUDENTACTIONRESPONSE"]._serialized_start = 1886
    _globals["_STUDENTACTIONRESPONSE"]._serialized_end = 2028
    _globals["_STUDENTACTIONRESPONSEBODY"]._serialized_start = 2030
    _globals["_STUDENTACTIONRESPONSEBODY"]._serialized_end = 2108
    _globals["_ASSIGNMENTCORRECTIONREQUEST"]._serialized_start = 2111
    _globals["_ASSIGNMENTCORRECTIONREQUEST"]._serialized_end = 2265
    _globals["_ASSIGNMENTCORRECTIONREQUESTBODY"]._serialized_start = 2267
    _globals["_ASSIGNMENTCORRECTIONREQUESTBODY"]._serialized_end = 2312
    _globals["_ASSIGNMENTCORRECTIONRESPONSE"]._serialized_start = 2315
    _globals["_ASSIGNMENTCORRECTIONRESPONSE"]._serialized_end = 2471
    _globals["_ASSIGNMENTCORRECTIONRESPONSEBODY"]._serialized_start = 2473
    _globals["_ASSIGNMENTCORRECTIONRESPONSEBODY"]._serialized_end = 2574
    _globals["_ASSIGNMENT"]._serialized_start = 2577
    _globals["_ASSIGNMENT"]._serialized_end = 3234
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .memory_pb2 import CreateMemoryRequest
from .memory_pb2 import CreateMemoryRequestBody
from .memory_pb2 import CreateMemoryResponse
from .memory_pb2 import CreateMemoryResponseBody
from .memory_pb2 import AddMemoryRequest
from .memory_pb2 import AddMemoryRequestBody
from .memory_pb2 import AddMemoryResponse
from .memory_pb2 import AddMemoryResponseBody
from .memory_pb2 import DeleteMemoryRequest
from .memory_pb2 import DeleteMemoryRequestBody
from .memory_pb2 import DeleteMemoryResponse
from .memory_pb2 import DeleteMemoryResponseBody
from .memory_pb2_grpc import MemoryServicer
from .memory_pb2_grpc import MemoryStub
from .memory_pb2_grpc import add_MemoryServicer_to_server
from .memory_pb2_grpc import Memory
from .rag_pb2 import CreateSessionRequest
from .rag_pb2 import CreateSessionRequestBody
from .rag_pb2 import CreateSessionResponse
from .rag_pb2 import CreateSessionResponseBody
from .rag_pb2 import AddMessageRequest
from .rag_pb2 import AddMessageRequestBody
from .rag_pb2 import AddMessageResponse
from .rag_pb2 import AddMessageResponseBody
from .rag_pb2 import DeleteMessageRequest
from .rag_pb2 import DeleteMessageRequestBody
from .rag_pb2 import DeleteMessageResponse
from .rag_pb2 import DeleteMessageResponseBody
from .rag_pb2 import InteractionMetadata
from .rag_pb2 import MainHistoryMetaData
from .rag_pb2 import VectorIndex
from .rag_pb2 import Status
from .rag_pb2 import SenderType
from .rag_pb2_grpc import RAGServicer
from .rag_pb2_grpc import RAGStub
from .rag_pb2_grpc import add_RAGServicer_to_server
from .rag_pb2_grpc import RAG



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class AddGroupRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddGroupRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddGroupRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AddGroupRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.GroupMetaData
    def __init__(self, meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...) -> None: ...

class AddGroupResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddGroupResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddGroupResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AddGroupResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.GroupMetaData
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...,
    ) -> None: ...

class DetailGroupRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailGroupRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailGroupRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DetailGroupRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DetailGroupResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailGroupResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailGroupResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DetailGroupResponseBody(_message.Message):
    __slots__ = ("status", "meta", "studentList")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    STUDENTLIST_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.GroupMetaData
    studentList: _containers.RepeatedCompositeFieldContainer[_meta_pb2.GroupMetaData]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...,
        studentList: _Optional[_Iterable[_Union[_meta_pb2.GroupMetaData, _Mapping]]] = ...,
    ) -> None: ...

class ListGroupRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListGroupRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListGroupRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ListGroupRequestBody(_message.Message):
    __slots__ = ("teacherDid", "pageIndex", "pageSize")
    TEACHERDID_FIELD_NUMBER: _ClassVar[int]
    PAGEINDEX_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    teacherDid: str
    pageIndex: _wrappers_pb2.Int32Value
    pageSize: _wrappers_pb2.Int32Value
    def __init__(
        self,
        teacherDid: _Optional[str] = ...,
        pageIndex: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
        pageSize: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
    ) -> None: ...

class ListGroupResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListGroupResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListGroupResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ListGroupResponseBody(_message.Message):
    __slots__ = ("status", "list", "total")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.GroupMetaData]
    total: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.GroupMetaData, _Mapping]]] = ...,
        total: _Optional[int] = ...,
    ) -> None: ...

class UpdateGroupRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateGroupRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateGroupRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateGroupRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.GroupMetaData
    def __init__(self, meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...) -> None: ...

class UpdateGroupResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateGroupResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateGroupResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateGroupResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.GroupMetaData
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...,
    ) -> None: ...

class DeleteGroupRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteGroupRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteGroupRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteGroupRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DeleteGroupResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteGroupResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteGroupResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteGroupResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.GroupMetaData
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.GroupMetaData, _Mapping]] = ...,
    ) -> None: ...



# Generated by protobuf_init. Do not edit manually.
from .config_pb2 import GetConfigRequest
from .config_pb2 import GetConfigRequestBody
from .config_pb2 import GetConfigResponse
from .config_pb2 import GetConfigResponseBody
from .config_pb2 import SetConfigRequest
from .config_pb2 import SetConfigRequestBody
from .config_pb2 import SetConfigResponse
from .config_pb2 import SetConfigResponseBody
from .config_pb2 import ConfigMetadata
from .config_pb2 import ConfigTypeEnum
from .config_pb2_grpc import ConfigServicer
from .config_pb2_grpc import ConfigStub
from .config_pb2_grpc import add_ConfigServicer_to_server
from .config_pb2_grpc import Config



# -*- coding:utf-8 -*-
import codecs
import os.path

from google.protobuf.json_format import Parse

from yeying.api.common import CipherTypeEnum
from yeying.api.web3 import Identity, SecurityAlgorithm, BlockAddress
from yeying.client.model.identity import verify_identity
from yeying.client.utils import log_utils

from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
from cryptography.hazmat.backends import default_backend
from yeying.client.utils.string_utils import decode_base64

log = log_utils.get_logger(__name__)


def load(identity_str) -> Identity:
    if not identity_str:
        log.error(f"param identity is None")
        raise Exception("param identity is None")
    content = identity_str
    if os.path.isfile(identity_str):
        content = codecs.open(identity_str, "r").read()
    identity: Identity = Parse(content, Identity())
    passed = verify_identity(identity)
    if not passed:
        log.error(f"Invalid identity={identity.metadata.did}")
        raise Exception(f"Invalid identity={identity.metadata.did}")
    return identity


def convert_cipher_type_from(type_str: str) -> CipherTypeEnum:
    algorithm_map = {
        "AES-GCM": CipherTypeEnum.CIPHER_TYPE_AES_GCM_256,
        # 可以在此添加更多枚举值到算法名称的映射
    }
    # 获取对应的算法名称，如果找不到则返回默认值
    return algorithm_map.get(type_str, CipherTypeEnum.CIPHER_TYPE_AES_GCM_256)


def convert_to_algorithm_name(cipher_type: CipherTypeEnum) -> str:
    """将加密类型枚举转换为对应的算法名称

    Args:
        cipher_type: 加密类型枚举值

    Returns:
        对应的算法名称字符串
    """
    # 使用字典映射实现类似 switch-case 的功能
    algorithm_map = {
        CipherTypeEnum.CIPHER_TYPE_AES_GCM_256: "AES-GCM",
        # 可以在此添加更多枚举值到算法名称的映射
    }

    # 获取对应的算法名称，如果找不到则返回默认值
    return algorithm_map.get(cipher_type, "AES-GCM")


def compute_hash(content: bytes) -> bytes:
    """计算 SHA-256 哈希值"""
    digest = hashes.Hash(hashes.SHA256(), backend=default_backend())
    digest.update(content)
    return digest.finalize()


def derive_raw_key_from_string(algorithm_name: str, password: str) -> bytes:
    """
    从字符串派生原始密钥
    注意：Python 中通常直接返回密钥字节，而不是密钥对象
    """
    # 编码内容并计算哈希
    content_bytes = password.encode('utf-8')
    hash_bytes = compute_hash(content_bytes)

    # 根据算法类型处理密钥
    if "AES" in algorithm_name:
        # AES 需要固定长度的密钥 (16/24/32 字节)
        key_length = 32  # 使用 SHA256 的 32 字节作为 AES-256
        return hash_bytes[:key_length]
    elif "HMAC" in algorithm_name:
        # HMAC 可直接使用哈希值
        return hash_bytes
    else:
        raise ValueError(f"Unsupported algorithm: {algorithm_name}")


def decrypt(
        name: str,
        key: bytes,  # 原始密钥字节
        iv: bytes,  # 初始化向量
        content: bytes  # 密文字节
) -> bytes:
    # 根据算法名称创建相应的解密器
    if "AES-CBC" in name or "AES_CBC" in name:
        cipher = Cipher(
            algorithms.AES(key),
            modes.CBC(iv),
            backend=default_backend()
        )
        data_to_decrypt = content  # CBC模式使用完整密文
    elif "AES-GCM" in name or "AES_GCM" in name:
        # 对于 GCM 模式，分离认证标签（最后16字节）
        if len(content) < 16:
            raise ValueError("Invalid ciphertext for AES-GCM")
        data_to_decrypt = content[:-16]  # 实际密文（不含标签）
        tag = content[-16:]              # 认证标签
        cipher = Cipher(
            algorithms.AES(key),
            modes.GCM(iv, tag),  # 将标签传入GCM模式
            backend=default_backend()
        )
    else:
        raise ValueError(f"Unsupported algorithm: {name}")

    # 创建解密器并执行解密
    decrypt_instance = cipher.decryptor()
    # 关键修复：使用data_to_decrypt而非完整content
    plaintext = decrypt_instance.update(data_to_decrypt) + decrypt_instance.finalize()
    return plaintext


def decrypt_block_address(block_address: str, security_algorithm: SecurityAlgorithm, password: str) -> BlockAddress:
    # algorithm_name = convert_to_algorithm_name(convert_cipher_type_from(security_algorithm.name))
    algorithm_name = security_algorithm.name
    crypto_key = derive_raw_key_from_string(algorithm_name, password)
    plain = decrypt(algorithm_name, crypto_key, decode_base64(security_algorithm.iv), decode_base64(block_address))
    print(plain.decode())
    block = BlockAddress()
    block.ParseFromString(plain)
    print(f"block={type(block)}")
    return block






# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/node/node.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/node/node.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/node/node.proto\x12\x0fyeying.api.node\x1a\x1fyeying/api/common/message.proto\x1a\x1dyeying/api/common/model.proto"F\n\x12HealthCheckRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x7f\n\x13HealthCheckResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.node.HealthCheckResponseBody"L\n\x17HealthCheckResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"A\n\rWhoamiRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"u\n\x0eWhoamiResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.node.WhoamiResponseBody"|\n\x12WhoamiResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata2\xaf\x01\n\x04Node\x12Z\n\x0bHealthCheck\x12#.yeying.api.node.HealthCheckRequest\x1a$.yeying.api.node.HealthCheckResponse"\x00\x12K\n\x06Whoami\x12\x1e.yeying.api.node.WhoamiRequest\x1a\x1f.yeying.api.node.WhoamiResponse"\x00\x42\x11Z\x0fyeying/api/nodeb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.node.node_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/node"
    _globals["_HEALTHCHECKREQUEST"]._serialized_start = 111
    _globals["_HEALTHCHECKREQUEST"]._serialized_end = 181
    _globals["_HEALTHCHECKRESPONSE"]._serialized_start = 183
    _globals["_HEALTHCHECKRESPONSE"]._serialized_end = 310
    _globals["_HEALTHCHECKRESPONSEBODY"]._serialized_start = 312
    _globals["_HEALTHCHECKRESPONSEBODY"]._serialized_end = 388
    _globals["_WHOAMIREQUEST"]._serialized_start = 390
    _globals["_WHOAMIREQUEST"]._serialized_end = 455
    _globals["_WHOAMIRESPONSE"]._serialized_start = 457
    _globals["_WHOAMIRESPONSE"]._serialized_end = 574
    _globals["_WHOAMIRESPONSEBODY"]._serialized_start = 576
    _globals["_WHOAMIRESPONSEBODY"]._serialized_end = 700
    _globals["_NODE"]._serialized_start = 703
    _globals["_NODE"]._serialized_end = 878
# @@protoc_insertion_point(module_scope)
